nprompter
=========

A Notion backed web teleprompter.

## Installation  

```bash
pip install nprompter
```

**See the docs: [https://fferegrino.github.io/nprompter/](https://fferegrino.github.io/nprompter/)**

![](https://media.giphy.com/media/jioUQ1Jus86xwa2EBw/giphy.gif)
